Learn R Programming

wehoop (version 3.0.0)

.hhs_doc: Internal: GET an authenticated Her Hoop Stats page and parse it

Description

Internal: GET an authenticated Her Hoop Stats page and parse it

Usage

.hhs_doc(path, jar)

Value

An xml_document.

Arguments

path

Page path (beginning with /) or full URL.

jar

A session cookie jar from .hhs_login().