Learn R Programming

wehoop (version 3.0.0)

.hhs_request: Internal: an httr2 request bound to a Her Hoop Stats cookie jar

Description

Internal: an httr2 request bound to a Her Hoop Stats cookie jar

Usage

.hhs_request(url, jar)

Arguments