dot-hhs_doc: Internal: GET an authenticated Her Hoop Stats page and parse...

.hhs_docR Documentation

Internal: GET an authenticated Her Hoop Stats page and parse it

Description

Internal: GET an authenticated Her Hoop Stats page and parse it

Usage

.hhs_doc(path, jar)

Arguments

path

Page path (beginning with /) or full URL.

jar

A session cookie jar from .hhs_login().

Value

An xml_document.


wehoop documentation built on Aug. 25, 2026, 1:06 a.m.