dot-hhs_request: Internal: an httr2 request bound to a Her Hoop Stats cookie...

.hhs_requestR Documentation

Internal: an httr2 request bound to a Her Hoop Stats cookie jar

Description

Internal: an httr2 request bound to a Her Hoop Stats cookie jar

Usage

.hhs_request(url, jar)

wehoop documentation built on Aug. 25, 2026, 1:06 a.m.