espn_basketball_game_all_player_player_schema: Shared column schema: espn basketball game all player player...

espn_basketball_game_all_player_player_schemaR Documentation

Shared column schema: espn basketball game all player player schema

Description

Columns shared verbatim across: espn_wbb_game_all, espn_wbb_player_box.

Details

col_name types description
game_id integer Unique game identifier.
season integer Season identifier (4-digit year or 'YYYY-YY' string).
season_type integer Season type (1=pre-season, 2=regular season, 3=postseason, 4=off-season for ESPN; or string label for WNBA Stats).
game_date Date Game date (YYYY-MM-DD).
game_date_time POSIXct Game start date/time (ISO 8601).
athlete_id integer Unique athlete identifier (ESPN).
athlete_display_name character Athlete display name (full).
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_location character Team city or location string.
team_short_display_name character Short team display name (e.g. 'Aces').
minutes numeric Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
field_goals_made integer Field goals made (2-pt + 3-pt).
field_goals_attempted integer Field goal attempts (2-pt + 3-pt).
three_point_field_goals_made integer Three-point field goals made.
three_point_field_goals_attempted integer Three-point field goal attempts.
free_throws_made integer Free throws made.
free_throws_attempted integer Free throw attempts.
offensive_rebounds integer Offensive rebounds.
defensive_rebounds integer Defensive rebounds.
rebounds integer Total rebounds.
assists integer Total assists.
steals integer Total steals.
blocks integer Total blocks.
turnovers integer Total turnovers.
fouls integer Personal fouls.
points integer Points scored.
starter logical TRUE if the player was in the starting lineup; FALSE otherwise.
ejected logical TRUE if the player was ejected from the game.
did_not_play logical TRUE if the player did not appear in the game.
active logical TRUE if the row represents an active record (player / team / season).
athlete_jersey character Athlete jersey number.
athlete_short_name character Athlete short display name.
athlete_headshot_href character Athlete headshot image URL.
athlete_position_name character Athlete position ('Guard', 'Forward', 'Center').
athlete_position_abbreviation character Athlete position abbreviation (G / F / C).
team_display_name character Full team display name.
team_uid character ESPN universal team identifier (UID format 's:40~l:...~t:...').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
team_logo character Team logo image URL.
team_abbreviation character Short team abbreviation (e.g. 'LAS').
team_color character Team primary color (hex without leading '#').
team_alternate_color character Team alternate color (hex without leading '#').
home_away character Game venue label ('home' or 'away').
team_winner logical TRUE if the team won this game.
team_score integer Team's score / final score.
opponent_team_id integer Unique identifier for the opponent team.
opponent_team_name character Opponent team display name.
opponent_team_location character Opponent team city / location.
opponent_team_display_name character Opponent team full display name.
opponent_team_abbreviation character Opponent team abbreviation.
opponent_team_logo character Opponent team logo URL.
opponent_team_color character Opponent team primary color (hex).
opponent_team_alternate_color character Opponent team alternate color (hex).
opponent_team_score integer Opponent team's score.

wehoop documentation built on Aug. 25, 2026, 1:06 a.m.