View source: R/espn_wnba_team_deep.R
| espn_wnba_team_season_roster | R Documentation |
Returns the per-season team roster as a tibble of athlete IDs from
seasons/{y}/teams/{id}/athletes. Distinct from espn_wnba_team_roster()
which targets a site-v2 endpoint optimized for the current season; this
core-v2 variant is era-correct and available back to ESPN's earliest
season for each league.
espn_wnba_team_season_roster(team_id, season = most_recent_wnba_season(), ...)
team_id |
ESPN team identifier. |
season |
Season year. Defaults to most recent WNBA season. |
... |
Additional arguments; currently unused. |
Get ESPN WNBA Team Roster (Per-Season, core-v2)
A tibble with one row per athlete on the season roster.
| col_name | types | description |
| league | character | League slug. |
| team_id | character | ESPN team id. |
| season | integer | Season year. |
| athlete_id | character | ESPN athlete id. |
| ref | character | $ref URL to athlete-in-season detail. |
Saiem Gilani
Other ESPN WNBA Functions:
espn_wnba_athletes_index(),
espn_wnba_award(),
espn_wnba_calendar(),
espn_wnba_coach_season(),
espn_wnba_coaches(),
espn_wnba_conferences(),
espn_wnba_draft(),
espn_wnba_draft_athlete_detail(),
espn_wnba_draft_pick(),
espn_wnba_draft_rounds(),
espn_wnba_franchise(),
espn_wnba_franchises(),
espn_wnba_freeagents(),
espn_wnba_futures(),
espn_wnba_game_all(),
espn_wnba_game_odds(),
espn_wnba_game_official_detail(),
espn_wnba_game_play(),
espn_wnba_game_play_personnel(),
espn_wnba_game_player_box(),
espn_wnba_game_probabilities(),
espn_wnba_game_propbets(),
espn_wnba_game_team_linescores(),
espn_wnba_game_team_roster_entry(),
espn_wnba_injuries(),
espn_wnba_leaders(),
espn_wnba_news(),
espn_wnba_player_awards(),
espn_wnba_player_career_stats(),
espn_wnba_player_eventlog_v2(),
espn_wnba_player_info(),
espn_wnba_player_overview(),
espn_wnba_player_seasons(),
espn_wnba_player_stats(),
espn_wnba_position(),
espn_wnba_positions(),
espn_wnba_powerindex(),
espn_wnba_scoreboard(),
espn_wnba_season_awards(),
espn_wnba_season_group(),
espn_wnba_season_groups(),
espn_wnba_season_info(),
espn_wnba_season_leaders(),
espn_wnba_season_ranking(),
espn_wnba_season_rankings(),
espn_wnba_season_type(),
espn_wnba_season_types(),
espn_wnba_season_week(),
espn_wnba_season_weeks(),
espn_wnba_seasons(),
espn_wnba_standings(),
espn_wnba_team(),
espn_wnba_team_injuries(),
espn_wnba_team_news(),
espn_wnba_team_record(),
espn_wnba_team_record_detail(),
espn_wnba_team_schedule(),
espn_wnba_team_season_statistics(),
espn_wnba_team_stats(),
espn_wnba_teams(),
espn_wnba_transactions(),
espn_wnba_venues(),
espn_wnba_week_ranking(),
espn_wnba_week_rankings()
espn_wnba_team_season_roster(team_id = 17, season = 2025)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.