Learn R Programming

wehoop (version 3.0.0)

fox_wnba_team_roster: Get Fox Sports basketball team roster

Description

Get Fox Sports (Bifrost) WNBA / women's college basketball (WBB) team roster. fox_wnba_team_roster() hits the wnba slug; fox_wbb_team_roster() hits the wcbk slug.

Get Fox Sports (Bifrost) WNBA / women's college basketball (WBB) team stat leaders. fox_wnba_team_stats() hits the wnba slug; fox_wbb_team_stats() hits the wcbk slug.

Get Fox Sports (Bifrost) WNBA / women's college basketball (WBB) team game log. fox_wnba_team_gamelog() hits the wnba slug; fox_wbb_team_gamelog() hits the wcbk slug.

Get Fox Sports (Bifrost) WNBA / women's college basketball (WBB) standings. fox_wnba_standings() hits the wnba slug; fox_wbb_standings() hits the wcbk slug.

Get the Fox Sports (Bifrost) WNBA / women's college basketball (WBB) team directory, derived from the standings endpoint. fox_wnba_teams() hits the wnba slug; fox_wbb_teams() hits the wcbk slug.

Usage

fox_wnba_team_roster(team_id)

fox_wbb_team_roster(team_id)

fox_wnba_team_stats(team_id)

fox_wbb_team_stats(team_id)

fox_wnba_team_gamelog(team_id)

fox_wbb_team_gamelog(team_id)

fox_wnba_standings(team_id)

fox_wbb_standings(team_id)

fox_wnba_teams(team_id = "3")

fox_wbb_teams(team_id = "11")

Value

A wehoop_data tibble, one row per player: team_id, position_group, player, position/age/etc. columns, athlete_id.

A wehoop_data tibble: team_id, category, stat, stat_abbreviation, player, value.

A wehoop_data tibble (long): team_id, season_type, category, game_id, game_date, opponent, stat, value.

A wehoop_data tibble of standings rows (team_id, section, the standings columns, entity_id).

A wehoop_data tibble, one row per team: fox_team_id, fox_team_name, fox_section.

Arguments

team_id

Fox Bifrost seed team id used to fetch league standings (default "3"). The standings response enumerates every team in the seed's league sections.

See Also

Other Fox Sports Functions: fox_basketball_league_leaders, fox_wbb_teams_all(), fox_wnba_pbp()

Examples

Run this code
# \donttest{
  try(fox_wnba_team_roster("1"))
# }
# \donttest{
  try(fox_wbb_team_roster("11"))
# }
# \donttest{
  try(fox_wnba_team_stats("1"))
# }
# \donttest{
  try(fox_wbb_team_stats("11"))
# }
# \donttest{
  try(fox_wnba_team_gamelog("1"))
# }
# \donttest{
  try(fox_wbb_team_gamelog("11"))
# }
# \donttest{
  try(fox_wnba_standings("1"))
# }
# \donttest{
  try(fox_wbb_standings("11"))
# }
# \donttest{
  try(fox_wnba_teams())
# }
# \donttest{
  try(fox_wbb_teams("11"))
# }

Run the code above in your browser using DataLab