load_wbb_player_crosswalk: *Load cached WNBA team crosswalk from the data repo*

View source: R/load_crosswalk.R

load_wnba_team_crosswalkR Documentation

Load cached WNBA team crosswalk from the data repo

Description

Loads cached team-crosswalk snapshots that map ESPN team identifiers to WNBA Stats API team identifiers. One row per team-season. Backed by the wnba_crosswalk release tag in sportsdataverse-data.

Loads cached schedule-crosswalk snapshots that map ESPN game identifiers to WNBA Stats API game identifiers. One row per game-season. Backed by the wnba_crosswalk release tag in sportsdataverse-data.

Loads cached player-crosswalk snapshots that map ESPN athlete identifiers to WNBA Stats API player identifiers. One row per athlete-season. Backed by the wnba_crosswalk release tag in sportsdataverse-data.

Loads cached team-crosswalk snapshots that map ESPN team identifiers to Fox Sports and Bart Torvik team identifiers for Women's College Basketball. One row per team-season. Backed by the wbb_crosswalk release tag in sportsdataverse-data.

Loads cached schedule-crosswalk snapshots that map ESPN game identifiers to Bart Torvik game identifiers for Women's College Basketball. One row per game-season. Backed by the wbb_crosswalk release tag in sportsdataverse-data.

Loads cached player-crosswalk snapshots that map ESPN athlete identifiers to Fox Sports player identifiers for Women's College Basketball. One row per athlete-season. Backed by the wbb_crosswalk release tag in sportsdataverse-data.

Usage

load_wnba_team_crosswalk(seasons = most_recent_wnba_season())

load_wnba_schedule_crosswalk(seasons = most_recent_wnba_season())

load_wnba_player_crosswalk(seasons = most_recent_wnba_season())

load_wbb_team_crosswalk(seasons = most_recent_wbb_season())

load_wbb_schedule_crosswalk(seasons = most_recent_wbb_season())

load_wbb_player_crosswalk(seasons = most_recent_wbb_season())

Arguments

seasons

A vector of 4-digit years associated with given WBB seasons. (Min: 2014)

Value

A wehoop_data tibble of cached team-crosswalk rows.

A wehoop_data tibble of cached schedule-crosswalk rows.

A wehoop_data tibble of cached player-crosswalk rows.

A wehoop_data tibble of cached WBB team-crosswalk rows.

A wehoop_data tibble of cached WBB schedule-crosswalk rows.

A wehoop_data tibble of cached WBB player-crosswalk rows.

See Also

Other WNBA Crosswalk Functions: wnba_player_crosswalk(), wnba_schedule_crosswalk(), wnba_team_crosswalk()

Other WBB Crosswalk Functions: wbb_player_crosswalk(), wbb_schedule_crosswalk(), wbb_team_crosswalk()

Examples


  try(load_wnba_team_crosswalk(seasons = most_recent_wnba_season()))


  try(load_wnba_schedule_crosswalk(seasons = most_recent_wnba_season()))


  try(load_wnba_player_crosswalk(seasons = most_recent_wnba_season()))


  try(load_wbb_team_crosswalk(seasons = most_recent_wbb_season()))


  try(load_wbb_schedule_crosswalk(seasons = most_recent_wbb_season()))


  try(load_wbb_player_crosswalk(seasons = most_recent_wbb_season()))


wehoop documentation built on Aug. 25, 2026, 1:06 a.m.