ncaa_wbb_NET_rankings: Get Women's college basketball NET rankings for the current...

View source: R/ncaa_wbb_data.R

ncaa_wbb_NET_rankingsR Documentation

Get Women's college basketball NET rankings for the current date from the NCAA website

Description

Get Women's college basketball NET rankings for the current date from the NCAA website

Usage

ncaa_wbb_NET_rankings()

Value

Returns a tibble

col_name types description
rank integer Whether to include statistical ranks in the returned table.
previous integer Previous.
school character Player's school / college (when distinct from 'college').
conference character Filter players or teams by conference.
record character Record string (e.g. '12-4').
road character Road.
neutral character Neutral.
home character Home.
non_div_i character Non div i.

Author(s)

Saiem Gilani

Examples

# Get current NCAA NET rankings

  try(ncaa_wbb_NET_rankings())


wehoop documentation built on Aug. 25, 2026, 1:06 a.m.