wehoop-package: wehoop: Access Women's Basketball Play by Play Data

wehoop-packageR Documentation

wehoop: Access Women's Basketball Play by Play Data

Description

logo

A utility for working with women's basketball data. A scraping and aggregating interface for the WNBA Stats API https://stats.wnba.com/ and ESPN's https://www.espn.com women's college basketball and WNBA statistics. It provides users with the capability to access the game play-by-plays, box scores, standings and results to analyze the data for themselves.

logo

A utility for working with women's basketball data. A scraping and aggregating interface for the WNBA Stats API https://stats.wnba.com/ and ESPN's https://www.espn.com women's college basketball and WNBA statistics. It provides users with the capability to access the game play-by-plays, box scores, standings and results to analyze the data for themselves.

Author(s)

Maintainer: Saiem Gilani saiem.gilani@gmail.com (ORCID) [copyright holder]

Authors:

See Also

Useful links:


wehoop documentation built on Aug. 25, 2026, 1:06 a.m.