wnba_boxscoretraditionalv3: *Get WNBA Stats API Boxscore Traditional V3*

View source: R/wnba_stats_boxscore_v3.R

wnba_boxscoretraditionalv3R Documentation

Get WNBA Stats API Boxscore Traditional V3

Description

Get WNBA Stats API Boxscore Traditional V3

Get WNBA Stats API Boxscore Traditional V3

Get WNBA Stats API Boxscore Advanced V3

Get WNBA Stats API Boxscore Misc V3

Get WNBA Stats API Boxscore Scoring V3

Get WNBA Stats API Boxscore Four Factors V3

Get WNBA Stats API Boxscore Player Tracking V3

Get WNBA Stats API Boxscore Usage V3

Usage

wnba_boxscoretraditionalv3(
  game_id = "1022200034",
  start_period = 0,
  end_period = 14,
  start_range = 0,
  end_range = 0,
  range_type = 0,
  ...
)

wnba_boxscoreadvancedv3(
  game_id = "1022200034",
  start_period = 0,
  end_period = 14,
  start_range = 0,
  end_range = 0,
  range_type = 0,
  ...
)

wnba_boxscoremiscv3(
  game_id = "1022200034",
  start_period = 0,
  end_period = 14,
  start_range = 0,
  end_range = 0,
  range_type = 0,
  ...
)

wnba_boxscorescoringv3(
  game_id = "1022200034",
  start_period = 0,
  end_period = 14,
  start_range = 0,
  end_range = 0,
  range_type = 0,
  ...
)

wnba_boxscorefourfactorsv3(
  game_id = "1022200034",
  start_period = 0,
  end_period = 14,
  start_range = 0,
  end_range = 0,
  range_type = 0,
  ...
)

wnba_boxscoreplayertrackv3(
  game_id = "1022200034",
  start_period = 0,
  end_period = 14,
  start_range = 0,
  end_range = 0,
  range_type = 0,
  ...
)

wnba_boxscoreusagev3(
  game_id = "1022200034",
  start_period = 0,
  end_period = 14,
  start_range = 0,
  end_range = 0,
  range_type = 0,
  ...
)

Arguments

game_id

Game ID - 10-digit zero-padded ID (e.g., '1022200034')

start_period

start_period

end_period

end_period

start_range

start_range

end_range

end_range

range_type

range_type

...

Additional arguments passed to an underlying function like httr.

Details

 wnba_boxscoretraditionalv3(game_id = "1022200034")
 wnba_boxscoreadvancedv3(game_id = "1022200034")
 wnba_boxscoremiscv3(game_id = "1022200034")
 wnba_boxscorescoringv3(game_id = "1022200034")
 wnba_boxscorefourfactorsv3(game_id = "1022200034")
 wnba_boxscoreplayertrackv3(game_id = "1022200034")
 wnba_boxscoreusagev3(game_id = "1022200034")

Value

A list of data frames: home_team_player_traditional, away_team_player_traditional, home_team_totals_traditional, away_team_totals_traditional, home_team_starters_totals, away_team_starters_totals, home_team_bench_totals, away_team_bench_totals

home_team_player_traditional

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
person_id integer Unique player identifier (V3 endpoints).
first_name character Player's first name.
family_name character Player's family / last name.
name_i character Initialed name (e.g. 'A. Wilson').
player_slug character URL-safe player identifier.
position character Listed roster position (G, F, C, etc.).
comment character Player status / inactive reason (e.g. 'DNP - Coach's Decision', 'Inactive').
jersey_num character Jersey number worn by the player.
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
field_goals_made integer Field goals made (2-pt + 3-pt).
field_goals_attempted integer Field goal attempts (2-pt + 3-pt).
field_goals_percentage numeric Field goal percentage (0-1 decimal).
three_pointers_made integer Three-point field goals made.
three_pointers_attempted integer Three-point field goal attempts.
three_pointers_percentage numeric Three-point field goal percentage (0-1 decimal).
free_throws_made integer Free throws made.
free_throws_attempted integer Free throw attempts.
free_throws_percentage numeric Free throw percentage (0-1 decimal).
rebounds_offensive integer Offensive rebounds.
rebounds_defensive integer Defensive rebounds.
rebounds_total integer Total rebounds.
assists integer Total assists.
steals integer Total steals.
blocks integer Total blocks.
turnovers integer Total turnovers.
fouls_personal integer Personal fouls.
points integer Points scored.
plus_minus_points numeric Plus/minus point differential while on court.

away_team_player_traditional

Same columns as the home_team_player_traditional table above.

home_team_totals_traditional

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
field_goals_made integer Field goals made (2-pt + 3-pt).
field_goals_attempted integer Field goal attempts (2-pt + 3-pt).
field_goals_percentage numeric Field goal percentage (0-1 decimal).
three_pointers_made integer Three-point field goals made.
three_pointers_attempted integer Three-point field goal attempts.
three_pointers_percentage numeric Three-point field goal percentage (0-1 decimal).
free_throws_made integer Free throws made.
free_throws_attempted integer Free throw attempts.
free_throws_percentage numeric Free throw percentage (0-1 decimal).
rebounds_offensive integer Offensive rebounds.
rebounds_defensive integer Defensive rebounds.
rebounds_total integer Total rebounds.
assists integer Total assists.
steals integer Total steals.
blocks integer Total blocks.
turnovers integer Total turnovers.
fouls_personal integer Personal fouls.
points integer Points scored.
plus_minus_points numeric Plus/minus point differential while on court.

away_team_totals_traditional

Same columns as the home_team_totals_traditional table above.

home_team_starters_totals

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
field_goals_made integer Field goals made (2-pt + 3-pt).
field_goals_attempted integer Field goal attempts (2-pt + 3-pt).
field_goals_percentage numeric Field goal percentage (0-1 decimal).
three_pointers_made integer Three-point field goals made.
three_pointers_attempted integer Three-point field goal attempts.
three_pointers_percentage numeric Three-point field goal percentage (0-1 decimal).
free_throws_made integer Free throws made.
free_throws_attempted integer Free throw attempts.
free_throws_percentage numeric Free throw percentage (0-1 decimal).
rebounds_offensive integer Offensive rebounds.
rebounds_defensive integer Defensive rebounds.
rebounds_total integer Total rebounds.
assists integer Total assists.
steals integer Total steals.
blocks integer Total blocks.
turnovers integer Total turnovers.
fouls_personal integer Personal fouls.
points integer Points scored.

away_team_starters_totals

Same columns as the home_team_starters_totals table above.

home_team_bench_totals

Same columns as the home_team_starters_totals table above.

away_team_bench_totals

Same columns as the home_team_starters_totals table above.

A list of data frames: home_team_player_advanced, away_team_player_advanced, home_team_totals_advanced, away_team_totals_advanced

home_team_player_advanced

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
person_id integer Unique player identifier (V3 endpoints).
first_name character Player's first name.
family_name character Player's family / last name.
name_i character Initialed name (e.g. 'A. Wilson').
player_slug character URL-safe player identifier.
position character Listed roster position (G, F, C, etc.).
comment character Player status / inactive reason (e.g. 'DNP - Coach's Decision', 'Inactive').
jersey_num character Jersey number worn by the player.
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
estimated_offensive_rating numeric Estimated offensive rating (points per 100 possessions estimate).
offensive_rating numeric Offensive rating (points per 100 possessions).
estimated_defensive_rating numeric Estimated defensive rating (points allowed per 100 possessions estimate).
defensive_rating numeric Defensive rating (points allowed per 100 possessions).
estimated_net_rating numeric Estimated net rating (off rating - def rating).
net_rating numeric Net rating (off rating - def rating).
assist_percentage numeric Assist percentage (0-1).
assist_to_turnover numeric Assist-to-turnover ratio.
assist_ratio numeric Assist ratio (assists per 100 possessions used).
offensive_rebound_percentage numeric Offensive rebound percentage (0-1).
defensive_rebound_percentage numeric Defensive rebound percentage (0-1).
rebound_percentage numeric Total rebound percentage (0-1).
turnover_ratio numeric Turnover ratio (turnovers per 100 possessions used).
effective_field_goal_percentage numeric Effective field goal percentage (0-1).
true_shooting_percentage numeric True shooting percentage (0-1).
usage_percentage numeric Usage percentage (0-1).
estimated_usage_percentage numeric Estimated usage percentage (0-1).
estimated_pace numeric Estimated possessions per 48 minutes.
pace numeric Possessions per 48 minutes.
pace_per40 numeric Pace per40.
possessions numeric Possessions used.
pie numeric Player Impact Estimate (0-1).

away_team_player_advanced

Same columns as the home_team_player_advanced table above.

home_team_totals_advanced

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
estimated_offensive_rating numeric Estimated offensive rating (points per 100 possessions estimate).
offensive_rating numeric Offensive rating (points per 100 possessions).
estimated_defensive_rating numeric Estimated defensive rating (points allowed per 100 possessions estimate).
defensive_rating numeric Defensive rating (points allowed per 100 possessions).
estimated_net_rating numeric Estimated net rating (off rating - def rating).
net_rating numeric Net rating (off rating - def rating).
assist_percentage numeric Assist percentage (0-1).
assist_to_turnover numeric Assist-to-turnover ratio.
assist_ratio numeric Assist ratio (assists per 100 possessions used).
offensive_rebound_percentage numeric Offensive rebound percentage (0-1).
defensive_rebound_percentage numeric Defensive rebound percentage (0-1).
rebound_percentage numeric Total rebound percentage (0-1).
estimated_team_turnover_percentage numeric Estimated team turnover percentage (0-1).
turnover_ratio numeric Turnover ratio (turnovers per 100 possessions used).
effective_field_goal_percentage numeric Effective field goal percentage (0-1).
true_shooting_percentage numeric True shooting percentage (0-1).
usage_percentage numeric Usage percentage (0-1).
estimated_usage_percentage numeric Estimated usage percentage (0-1).
estimated_pace numeric Estimated possessions per 48 minutes.
pace numeric Possessions per 48 minutes.
pace_per40 numeric Pace per40.
possessions numeric Possessions used.
pie numeric Player Impact Estimate (0-1).

away_team_totals_advanced

Same columns as the home_team_totals_advanced table above.

A list of data frames: home_team_player_misc, away_team_player_misc, home_team_totals_misc, away_team_totals_misc

home_team_player_misc

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
person_id integer Unique player identifier (V3 endpoints).
first_name character Player's first name.
family_name character Player's family / last name.
name_i character Initialed name (e.g. 'A. Wilson').
player_slug character URL-safe player identifier.
position character Listed roster position (G, F, C, etc.).
comment character Player status / inactive reason (e.g. 'DNP - Coach's Decision', 'Inactive').
jersey_num character Jersey number worn by the player.
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
points_off_turnovers integer Points scored off opponent turnovers.
points_second_chance integer Second-chance points scored.
points_fast_break integer Fast-break points scored.
points_paint integer Points scored in the paint.
opp_points_off_turnovers integer Opponent points off turnovers.
opp_points_second_chance integer Opponent points second chance.
opp_points_fast_break integer Opponent points fast break.
opp_points_paint integer Opponent points paint.
blocks integer Total blocks.
blocks_against integer Shots blocked by opponents while attempting.
fouls_personal integer Personal fouls.
fouls_drawn integer Personal fouls drawn (by opponent's actions).

away_team_player_misc

Same columns as the home_team_player_misc table above.

home_team_totals_misc

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
points_off_turnovers integer Points scored off opponent turnovers.
points_second_chance integer Second-chance points scored.
points_fast_break integer Fast-break points scored.
points_paint integer Points scored in the paint.
opp_points_off_turnovers integer Opponent points off turnovers.
opp_points_second_chance integer Opponent points second chance.
opp_points_fast_break integer Opponent points fast break.
opp_points_paint integer Opponent points paint.
blocks integer Total blocks.
blocks_against integer Shots blocked by opponents while attempting.
fouls_personal integer Personal fouls.
fouls_drawn integer Personal fouls drawn (by opponent's actions).

away_team_totals_misc

Same columns as the home_team_totals_misc table above.

A list of data frames: home_team_player_scoring, away_team_player_scoring, home_team_totals_scoring, away_team_totals_scoring

home_team_player_scoring

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
person_id integer Unique player identifier (V3 endpoints).
first_name character Player's first name.
family_name character Player's family / last name.
name_i character Initialed name (e.g. 'A. Wilson').
player_slug character URL-safe player identifier.
position character Listed roster position (G, F, C, etc.).
comment character Player status / inactive reason (e.g. 'DNP - Coach's Decision', 'Inactive').
jersey_num character Jersey number worn by the player.
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
percentage_field_goals_attempted2pt numeric Percentage field goals attempted2pt.
percentage_field_goals_attempted3pt numeric Percentage field goals attempted3pt.
percentage_points2pt numeric Percentage points2pt.
percentage_points_midrange2pt numeric Percentage points midrange2pt.
percentage_points3pt numeric Percentage points3pt.
percentage_points_fast_break numeric Percentage points fast break.
percentage_points_free_throw numeric Percentage points free throw.
percentage_points_off_turnovers numeric Percentage points off turnovers.
percentage_points_paint numeric Percentage points paint.
percentage_assisted2pt numeric Percentage assisted2pt.
percentage_unassisted2pt numeric Percentage unassisted2pt.
percentage_assisted3pt numeric Percentage assisted3pt.
percentage_unassisted3pt numeric Percentage unassisted3pt.
percentage_assisted_fgm numeric Percentage assisted fgm.
percentage_unassisted_fgm numeric Percentage unassisted fgm.

away_team_player_scoring

Same columns as the home_team_player_scoring table above.

home_team_totals_scoring

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
percentage_field_goals_attempted2pt numeric Percentage field goals attempted2pt.
percentage_field_goals_attempted3pt numeric Percentage field goals attempted3pt.
percentage_points2pt numeric Percentage points2pt.
percentage_points_midrange2pt numeric Percentage points midrange2pt.
percentage_points3pt numeric Percentage points3pt.
percentage_points_fast_break numeric Percentage points fast break.
percentage_points_free_throw numeric Percentage points free throw.
percentage_points_off_turnovers numeric Percentage points off turnovers.
percentage_points_paint numeric Percentage points paint.
percentage_assisted2pt numeric Percentage assisted2pt.
percentage_unassisted2pt numeric Percentage unassisted2pt.
percentage_assisted3pt numeric Percentage assisted3pt.
percentage_unassisted3pt numeric Percentage unassisted3pt.
percentage_assisted_fgm numeric Percentage assisted fgm.
percentage_unassisted_fgm numeric Percentage unassisted fgm.

away_team_totals_scoring

Same columns as the home_team_totals_scoring table above.

A list of data frames: home_team_player_four_factors, away_team_player_four_factors, home_team_totals_four_factors, away_team_totals_four_factors

home_team_player_four_factors

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
person_id integer Unique player identifier (V3 endpoints).
first_name character Player's first name.
family_name character Player's family / last name.
name_i character Initialed name (e.g. 'A. Wilson').
player_slug character URL-safe player identifier.
position character Listed roster position (G, F, C, etc.).
comment character Player status / inactive reason (e.g. 'DNP - Coach's Decision', 'Inactive').
jersey_num character Jersey number worn by the player.
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
effective_field_goal_percentage numeric Effective field goal percentage (0-1).
free_throw_attempt_rate numeric Free throw attempt rate (FTA / FGA).
team_turnover_percentage numeric Team turnover percentage (0-1).
offensive_rebound_percentage numeric Offensive rebound percentage (0-1).
opp_effective_field_goal_percentage numeric Opponent effective field goal percentage (0-1 decimal).
opp_free_throw_attempt_rate numeric Opponent free throw attempt rate.
opp_team_turnover_percentage numeric Opponent team turnover percentage (0-1 decimal).
opp_offensive_rebound_percentage numeric Opponent offensive rebound percentage (0-1 decimal).

away_team_player_four_factors

Same columns as the home_team_player_four_factors table above.

home_team_totals_four_factors

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
effective_field_goal_percentage numeric Effective field goal percentage (0-1).
free_throw_attempt_rate numeric Free throw attempt rate (FTA / FGA).
team_turnover_percentage numeric Team turnover percentage (0-1).
offensive_rebound_percentage numeric Offensive rebound percentage (0-1).
opp_effective_field_goal_percentage numeric Opponent effective field goal percentage (0-1 decimal).
opp_free_throw_attempt_rate numeric Opponent free throw attempt rate.
opp_team_turnover_percentage numeric Opponent team turnover percentage (0-1 decimal).
opp_offensive_rebound_percentage numeric Opponent offensive rebound percentage (0-1 decimal).

away_team_totals_four_factors

Same columns as the home_team_totals_four_factors table above.

A list of data frames: home_team_player_player_track, away_team_player_player_track, home_team_totals_player_track, away_team_totals_player_track

home_team_player_player_track

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
person_id integer Unique player identifier (V3 endpoints).
first_name character Player's first name.
family_name character Player's family / last name.
name_i character Initialed name (e.g. 'A. Wilson').
player_slug character URL-safe player identifier.
position character Listed roster position (G, F, C, etc.).
comment character Player status / inactive reason (e.g. 'DNP - Coach's Decision', 'Inactive').
jersey_num character Jersey number worn by the player.
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
speed numeric Speed.
distance numeric Distance value (in feet for shot data; otherwise context-dependent).
rebound_chances_offensive integer Rebound chances offensive.
rebound_chances_defensive integer Rebound chances defensive.
rebound_chances_total integer Rebound chances total.
touches integer Touches.
secondary_assists integer Secondary assists.
free_throw_assists integer Free throw assists (passes that led to a fouled shot attempt).
passes integer Passes.
assists integer Total assists.
contested_field_goals_made integer Contested field goals made.
contested_field_goals_attempted integer Contested field goal attempts.
contested_field_goal_percentage numeric Contested field goal percentage (0-1).
uncontested_field_goals_made integer Number of uncontested field goals made.
uncontested_field_goals_attempted integer Number of uncontested field goals attempted.
uncontested_field_goals_percentage numeric Uncontested field goals percentage (0-1 decimal).
field_goal_percentage numeric Field Goal Percentage.
defended_at_rim_field_goals_made integer Field goals made allowed when defending at the rim.
defended_at_rim_field_goals_attempted integer Field goal attempts allowed when defending at the rim.
defended_at_rim_field_goal_percentage numeric Field goal percentage allowed at the rim (0-1).

away_team_player_player_track

Same columns as the home_team_player_player_track table above.

home_team_totals_player_track

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
distance numeric Distance value (in feet for shot data; otherwise context-dependent).
rebound_chances_offensive integer Rebound chances offensive.
rebound_chances_defensive integer Rebound chances defensive.
rebound_chances_total integer Rebound chances total.
touches integer Touches.
secondary_assists integer Secondary assists.
free_throw_assists integer Free throw assists (passes that led to a fouled shot attempt).
passes integer Passes.
assists integer Total assists.
contested_field_goals_made integer Contested field goals made.
contested_field_goals_attempted integer Contested field goal attempts.
contested_field_goal_percentage numeric Contested field goal percentage (0-1).
uncontested_field_goals_made integer Number of uncontested field goals made.
uncontested_field_goals_attempted integer Number of uncontested field goals attempted.
uncontested_field_goals_percentage numeric Uncontested field goals percentage (0-1 decimal).
field_goal_percentage numeric Field Goal Percentage.
defended_at_rim_field_goals_made integer Field goals made allowed when defending at the rim.
defended_at_rim_field_goals_attempted integer Field goal attempts allowed when defending at the rim.
defended_at_rim_field_goal_percentage numeric Field goal percentage allowed at the rim (0-1).

away_team_totals_player_track

Same columns as the home_team_totals_player_track table above.

Returns a named list of data frames: home_team_player_usage, away_team_player_usage, home_team_totals_usage, away_team_totals_usage

home_team_player_usage

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
person_id integer Unique player identifier (V3 endpoints).
first_name character Player's first name.
family_name character Player's family / last name.
name_i character Initialed name (e.g. 'A. Wilson').
player_slug character URL-safe player identifier.
position character Listed roster position (G, F, C, etc.).
comment character Player status / inactive reason (e.g. 'DNP - Coach's Decision', 'Inactive').
jersey_num character Jersey number worn by the player.
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
usage_percentage numeric Usage percentage (0-1).
percentage_field_goals_made numeric Number of percentage field goals made.
percentage_field_goals_attempted numeric Number of percentage field goals attempted.
percentage_three_pointers_made numeric Number of percentage three pointers made.
percentage_three_pointers_attempted numeric Number of percentage three pointers attempted.
percentage_free_throws_made numeric Number of percentage free throws made.
percentage_free_throws_attempted numeric Number of percentage free throws attempted.
percentage_rebounds_offensive numeric Percentage rebounds offensive.
percentage_rebounds_defensive numeric Percentage rebounds defensive.
percentage_rebounds_total numeric Percentage rebounds total.
percentage_assists numeric Percentage assists.
percentage_turnovers numeric Percentage turnovers.
percentage_steals numeric Percentage steals.
percentage_blocks numeric Percentage blocks.
percentage_blocks_allowed numeric Percentage blocks allowed.
percentage_personal_fouls numeric Percentage personal fouls.
percentage_personal_fouls_drawn numeric Percentage personal fouls drawn.
percentage_points numeric Percentage points.

away_team_player_usage

Same columns as the home_team_player_usage table above.

home_team_totals_usage

col_name types description
game_id character Unique game identifier.
away_team_id integer Unique identifier for the away team.
home_team_id integer Unique identifier for the home team.
team_id integer Unique team identifier.
team_name character Full team display name (e.g. 'Las Vegas Aces').
team_city character Team city or region (e.g. 'Las Vegas').
team_tricode character Three-letter team code (e.g. 'LAS' / 'NYL').
team_slug character URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
minutes character Minutes played, formatted MM:SS (V3 PT-duration parsed) or decimal minutes (V2).
usage_percentage numeric Usage percentage (0-1).
percentage_field_goals_made numeric Number of percentage field goals made.
percentage_field_goals_attempted numeric Number of percentage field goals attempted.
percentage_three_pointers_made numeric Number of percentage three pointers made.
percentage_three_pointers_attempted numeric Number of percentage three pointers attempted.
percentage_free_throws_made numeric Number of percentage free throws made.
percentage_free_throws_attempted numeric Number of percentage free throws attempted.
percentage_rebounds_offensive numeric Percentage rebounds offensive.
percentage_rebounds_defensive numeric Percentage rebounds defensive.
percentage_rebounds_total numeric Percentage rebounds total.
percentage_assists numeric Percentage assists.
percentage_turnovers numeric Percentage turnovers.
percentage_steals numeric Percentage steals.
percentage_blocks numeric Percentage blocks.
percentage_blocks_allowed numeric Percentage blocks allowed.
percentage_personal_fouls numeric Percentage personal fouls.
percentage_personal_fouls_drawn numeric Percentage personal fouls drawn.
percentage_points numeric Percentage points.

away_team_totals_usage

Same columns as the home_team_totals_usage table above.

Author(s)

Saiem Gilani

See Also

Other WNBA Boxscore V3 Functions: wnba_boxscorehustlev2(), wnba_boxscoresummaryv3()


wehoop documentation built on Aug. 25, 2026, 1:06 a.m.