View source: R/wnba_stats_leaders.R
| wnba_leagueleaders | R Documentation |
Get WNBA Stats API League Leaders
Get WNBA Stats API League Leaders
wnba_leagueleaders(
active_flag = "",
league_id = "10",
per_mode = "Totals",
scope = "S",
season = most_recent_wnba_season() - 1,
season_type = "Regular Season",
stat_category = "PTS",
...
)
active_flag |
Active Flag |
league_id |
League - default: '00'. Other options include '10': WNBA, '20': G-League |
per_mode |
Per Mode - Totals, PerGame, Per48 |
scope |
Scope - RS, S, Rookies |
season |
Season - format 2020-21 |
season_type |
Season Type - Regular Season, Playoffs |
stat_category |
Stat Category: PTS, REB, AST, FG_PCT, FT_PCT, FG3_PCT, STL, BLK |
... |
Additional arguments passed to an underlying function like httr. |
wnba_leagueleaders(league_id = '10')
Returns a named list of data frames: LeagueLeaders
LeagueLeaders
| col_name | types | description |
| PLAYER_ID | character | Unique player identifier. |
| RANK | character | Whether to include statistical ranks in the returned table. |
| PLAYER | character | |
| TEAM_ID | character | Unique team identifier. |
| TEAM | character | Team-side label or team identifier. |
| GP | character | Games played. |
| MIN | character | Minutes played. |
| FGM | character | Field goals made. |
| FGA | character | Field goal attempts. |
| FG_PCT | character | Field goal percentage (0-1). |
| FG3M | character | Three-point field goals made. |
| FG3A | character | Three-point field goal attempts. |
| FG3_PCT | character | Three-point field goal percentage (0-1). |
| FTM | character | Free throws made. |
| FTA | character | Free throw attempts. |
| FT_PCT | character | Free throw percentage (0-1). |
| OREB | character | Offensive rebounds. |
| DREB | character | Defensive rebounds. |
| REB | character | Total rebounds. |
| AST | character | Assists. |
| STL | character | Steals. |
| BLK | character | Blocks. |
| TOV | character | Turnovers. |
| PF | character | Personal fouls. |
| PTS | character | Points scored. |
| EFF | character | |
| AST_TOV | character | |
| STL_TOV | character | |
Saiem Gilani
Other WNBA Leaders Functions:
wnba_alltimeleadersgrids(),
wnba_assistleaders(),
wnba_assisttracker(),
wnba_homepagewidget()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.