wnba_pbps: *Get WNBA Stats API play-by-play (Multiple Games)*

View source: R/wnba_stats_pbp.R

wnba_pbpsR Documentation

Get WNBA Stats API play-by-play (Multiple Games)

Description

Get WNBA Stats API play-by-play (Multiple Games)

Get WNBA Stats API play-by-play (Multiple Games)

Usage

wnba_pbps(
  game_ids = NULL,
  on_court = TRUE,
  version = "v3",
  nest_data = FALSE,
  ...
)

Arguments

game_ids

Game IDs

on_court

IF TRUE will be added ID of players on court

version

Play-by-play version - "v3" (default) or "v2". V3 returns richer data with shot coordinates, shot values, and V3 action types. V2 is available from 2016-17 onwards.

nest_data

If TRUE returns nested data by game

...

Additional arguments passed to an underlying function like httr.

Details

y <- c("1022200034", "1022200035" )

wnba_pbps(game_ids = y, version = "v2")

Value

Returns a data frame: PlayByPlay

Columns as documented in the shared wnba_players_on_court_schema table.

Author(s)

Jason Lee

See Also

Other WNBA PBP Functions: wnba_data_pbp(), wnba_live_pbp(), wnba_pbp(), wnba_playbyplayv3()


wehoop documentation built on Aug. 25, 2026, 1:06 a.m.