Learn R Programming

wehoop (version 3.0.0)

espn_basketball_scoreboard_schema: Shared column schema: espn basketball scoreboard schema

Description

Columns shared verbatim across: espn_wbb_scoreboard, espn_wnba_scoreboard.

Arguments

Details

col_nametypesdescription
matchupcharacterMatchup.
matchup_shortcharacterMatchup short.
seasonintegerSeason identifier (4-digit year or 'YYYY-YY' string).
season_typeintegerSeason type (1=pre-season, 2=regular season, 3=postseason, 4=off-season for ESPN; or string label for WNBA Stats).
season_slugcharacterSeason slug.
game_idintegerUnique game identifier.
game_uidcharacterGame uid.
game_dateDateGame date (YYYY-MM-DD).
attendanceintegerReported attendance.
status_namecharacterStatus label.
broadcast_marketcharacterBroadcast market label (e.g. 'national', 'home').
broadcast_namecharacterBroadcast name.
start_datecharacterStart date (YYYY-MM-DD).
game_date_timePOSIXctGame start date/time (ISO 8601).
home_team_namecharacterHome team name.
home_team_logocharacterHome team logo URL.
home_team_abbcharacterHome team's team abb.
home_team_idintegerUnique identifier for the home team.
home_team_locationcharacterHome team's team location.
home_team_full_namecharacterFull home team name (e.g. 'Las Vegas Aces').
home_team_colorcharacterHome team primary color (hex).
home_scoreintegerHome team score at the time of the play.
home_winintegerHome team's win.
home_recordcharacterHome win-loss record.
away_team_namecharacterAway team name.
away_team_logocharacterAway team logo URL.
away_team_abbcharacterAway team's team abb.
away_team_idintegerUnique identifier for the away team.
away_team_locationcharacterAway team's team location.
away_team_full_namecharacterFull away team name (e.g. 'Las Vegas Aces').
away_team_colorcharacterAway team primary color (hex).
away_scoreintegerAway team score at the time of the play.
away_winintegerAway team's win.
away_recordcharacterAway win-loss record.