View source: R/espn_wbb_data.R
| espn_wbb_game_all | R Documentation |
Get ESPN women's college basketball game data (play-by-play, team and player box)
Get ESPN women's college basketball play by play data
Get ESPN women's college basketball team box data
Get ESPN women's college basketball player box
Get ESPN women's college basketball game rosters
espn_wbb_game_all(game_id)
espn_wbb_pbp(game_id)
espn_wbb_team_box(game_id)
espn_wbb_player_box(game_id)
espn_wbb_game_rosters(game_id)
game_id |
Game ID |
A named list of dataframes: Plays, Team, Player
Plays
Columns as documented in the shared espn_basketball_game_all_plays_plays_schema table.
Team
Columns as documented in the shared espn_basketball_team_box_schema table.
Player
Columns as documented in the shared espn_basketball_game_all_player_player_schema table.
Returns a play-by-play data frame
Plays
Columns as documented in the shared espn_basketball_game_all_plays_plays_schema table.
Returns a team boxscore data frame
Team
Columns as documented in the shared espn_basketball_team_box_schema table.
Returns a player boxscore data frame
Player
Columns as documented in the shared espn_basketball_game_all_player_player_schema table.
A game rosters data frame
| col_name | types | description |
| athlete_id | integer | Unique athlete identifier (ESPN). |
| athlete_uid | character | ESPN athlete UID (universal identifier). |
| athlete_guid | character | ESPN athlete GUID. |
| athlete_type | character | Athlete type / class. |
| sdr | integer | Sdr. |
| first_name | character | Player's first name. |
| last_name | character | Player's last name. |
| full_name | character | Player's full name. |
| athlete_display_name | character | Athlete display name (full). |
| short_name | character | Short display name. |
| height | integer | Player height (string e.g. '6-2' or inches). |
| display_height | character | Player height in display format (e.g. '6-2'). |
| birth_place_city | character | Birth place city. |
| birth_place_state | character | Birth place state. |
| birth_place_country | character | Birth place country. |
| slug | character | URL-safe identifier. |
| headshot_href | character | Headshot image URL. |
| headshot_alt | character | Alternative-text label for the headshot. |
| jersey | character | Jersey number worn by the player. |
| position_id | integer | Unique position identifier. |
| position_name | character | Listed roster position ('Guard', 'Forward', 'Center'). |
| position_display_name | character | Position display name. |
| position_abbreviation | character | Position abbreviation ('G' / 'F' / 'C'). |
| position_leaf | logical | Position leaf. |
| linked | logical | TRUE if the record is linked to a related entity. |
| experience_years | integer | Experience years. |
| experience_display_value | character | Experience display value. |
| experience_abbreviation | character | Experience abbreviation. |
| active | logical | TRUE if the row represents an active record (player / team / season). |
| status_id | integer | Status identifier. |
| status_name | character | Status label. |
| status_type | character | Status type. |
| status_abbreviation | character | Status abbreviation. |
| starter | logical | TRUE if the player was in the starting lineup; FALSE otherwise. |
| valid | logical | Valid. |
| did_not_play | logical | TRUE if the player did not appear in the game. |
| display_name | character | Display name. |
| ejected | logical | TRUE if the player was ejected from the game. |
| team_id | integer | Unique team identifier. |
| team_guid | character | ESPN team GUID. |
| team_uid | character | ESPN universal team identifier (UID format 's:40~l:...~t:...'). |
| team_sdr | integer | ESPN team SDR identifier. |
| team_slug | character | URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces'). |
| team_location | character | Team city or location string. |
| team_name | character | Full team display name (e.g. 'Las Vegas Aces'). |
| team_nickname | character | Team nickname. |
| team_abbreviation | character | Short team abbreviation (e.g. 'LAS'). |
| team_display_name | character | Full team display name. |
| team_short_display_name | character | Short team display name (e.g. 'Aces'). |
| team_color | character | Team primary color (hex without leading '#'). |
| team_alternate_color | character | Team alternate color (hex without leading '#'). |
| is_active | logical | Is active. |
| is_all_star | logical | Is all star. |
| logo_href | character | Team or league logo URL. |
| logo_dark_href | character | Logo URL for dark backgrounds. |
| game_id | integer | Unique game identifier. |
| order | integer | Display order within the result set. |
| home_away | character | Game venue label ('home' or 'away'). |
| winner | logical | Winner. |
| roster_href | character | URL for roster. |
| hand_type | character | Hand type. |
| hand_abbreviation | character | Hand abbreviation. |
| hand_display_value | character | Hand display value. |
| age | integer | Player age (in years). |
| date_of_birth | character | Date of birth (YYYY-MM-DD). |
| weight | integer | Player weight in pounds. |
| display_weight | character | Player weight in display format (e.g. '180 lbs'). |
Saiem Gilani
Other ESPN WBB Functions:
espn_wbb_athletes_index(),
espn_wbb_award(),
espn_wbb_calendar(),
espn_wbb_coach(),
espn_wbb_coach_record(),
espn_wbb_coach_season(),
espn_wbb_coaches(),
espn_wbb_conferences(),
espn_wbb_franchise(),
espn_wbb_franchises(),
espn_wbb_game_odds(),
espn_wbb_game_official_detail(),
espn_wbb_game_play(),
espn_wbb_game_play_personnel(),
espn_wbb_game_player_box(),
espn_wbb_game_probabilities(),
espn_wbb_game_propbets(),
espn_wbb_game_team_linescores(),
espn_wbb_game_team_roster_entry(),
espn_wbb_injuries(),
espn_wbb_leaders(),
espn_wbb_news(),
espn_wbb_player_awards(),
espn_wbb_player_career_stats(),
espn_wbb_player_eventlog_v2(),
espn_wbb_player_info(),
espn_wbb_player_overview(),
espn_wbb_player_seasons(),
espn_wbb_player_stats(),
espn_wbb_position(),
espn_wbb_positions(),
espn_wbb_powerindex(),
espn_wbb_rankings(),
espn_wbb_scoreboard(),
espn_wbb_season_awards(),
espn_wbb_season_group(),
espn_wbb_season_groups(),
espn_wbb_season_info(),
espn_wbb_season_leaders(),
espn_wbb_season_ranking(),
espn_wbb_season_rankings(),
espn_wbb_season_type(),
espn_wbb_season_types(),
espn_wbb_season_week(),
espn_wbb_season_weeks(),
espn_wbb_seasons(),
espn_wbb_standings(),
espn_wbb_team(),
espn_wbb_team_injuries(),
espn_wbb_team_news(),
espn_wbb_team_record_detail(),
espn_wbb_team_schedule(),
espn_wbb_team_season_roster(),
espn_wbb_team_season_statistics(),
espn_wbb_team_stats(),
espn_wbb_teams(),
espn_wbb_tournament(),
espn_wbb_tournament_season(),
espn_wbb_tournament_seasons(),
espn_wbb_tournaments(),
espn_wbb_venues(),
espn_wbb_week_ranking(),
espn_wbb_week_rankings()
try(espn_wbb_game_all(game_id = 401276115))
try(espn_wbb_pbp(game_id = 401498717))
try(espn_wbb_team_box(game_id = 401276115))
try(espn_wbb_player_box(game_id = 401276115))
try(espn_wbb_game_rosters(game_id = 401276115))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.