Learn R Programming

wehoop (version 3.0.0)

espn_wbb_game_all: Get ESPN women's college basketball game data (play-by-play, team and player box)

Description

Get ESPN women's college basketball game data (play-by-play, team and player box)

Get ESPN women's college basketball play by play data

Get ESPN women's college basketball team box data

Get ESPN women's college basketball player box

Get ESPN women's college basketball game rosters

Usage

espn_wbb_game_all(game_id)

espn_wbb_pbp(game_id)

espn_wbb_team_box(game_id)

espn_wbb_player_box(game_id)

espn_wbb_game_rosters(game_id)

Value

A named list of dataframes: Plays, Team, Player

Plays

Columns as documented in the shared espn_basketball_game_all_plays_plays_schema table.

Team

Columns as documented in the shared espn_basketball_team_box_schema table.

Player

Columns as documented in the shared espn_basketball_game_all_player_player_schema table.

Returns a play-by-play data frame

Plays

Columns as documented in the shared espn_basketball_game_all_plays_plays_schema table.

Returns a team boxscore data frame

Team

Columns as documented in the shared espn_basketball_team_box_schema table.

Returns a player boxscore data frame

Player

Columns as documented in the shared espn_basketball_game_all_player_player_schema table.

A game rosters data frame

col_nametypesdescription
athlete_idintegerUnique athlete identifier (ESPN).
athlete_uidcharacterESPN athlete UID (universal identifier).
athlete_guidcharacterESPN athlete GUID.
athlete_typecharacterAthlete type / class.
sdrintegerSdr.
first_namecharacterPlayer's first name.
last_namecharacterPlayer's last name.
full_namecharacterPlayer's full name.
athlete_display_namecharacterAthlete display name (full).
short_namecharacterShort display name.
heightintegerPlayer height (string e.g. '6-2' or inches).
display_heightcharacterPlayer height in display format (e.g. '6-2').
birth_place_citycharacterBirth place city.
birth_place_statecharacterBirth place state.
birth_place_countrycharacterBirth place country.
slugcharacterURL-safe identifier.
headshot_hrefcharacterHeadshot image URL.
headshot_altcharacterAlternative-text label for the headshot.
jerseycharacterJersey number worn by the player.
position_idintegerUnique position identifier.
position_namecharacterListed roster position ('Guard', 'Forward', 'Center').
position_display_namecharacterPosition display name.
position_abbreviationcharacterPosition abbreviation ('G' / 'F' / 'C').
position_leaflogicalPosition leaf.
linkedlogicalTRUE if the record is linked to a related entity.
experience_yearsintegerExperience years.
experience_display_valuecharacterExperience display value.
experience_abbreviationcharacterExperience abbreviation.
activelogicalTRUE if the row represents an active record (player / team / season).
status_idintegerStatus identifier.
status_namecharacterStatus label.
status_typecharacterStatus type.
status_abbreviationcharacterStatus abbreviation.
starterlogicalTRUE if the player was in the starting lineup; FALSE otherwise.
validlogicalValid.
did_not_playlogicalTRUE if the player did not appear in the game.
display_namecharacterDisplay name.
ejectedlogicalTRUE if the player was ejected from the game.
team_idintegerUnique team identifier.
team_guidcharacterESPN team GUID.
team_uidcharacterESPN universal team identifier (UID format 's:40~l:...~t:...').
team_sdrintegerESPN team SDR identifier.
team_slugcharacterURL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
team_locationcharacterTeam city or location string.
team_namecharacterFull team display name (e.g. 'Las Vegas Aces').
team_nicknamecharacterTeam nickname.
team_abbreviationcharacterShort team abbreviation (e.g. 'LAS').
team_display_namecharacterFull team display name.
team_short_display_namecharacterShort team display name (e.g. 'Aces').
team_colorcharacterTeam primary color (hex without leading '#').
team_alternate_colorcharacterTeam alternate color (hex without leading '#').
is_activelogicalIs active.
is_all_starlogicalIs all star.
logo_hrefcharacterTeam or league logo URL.
logo_dark_hrefcharacterLogo URL for dark backgrounds.
game_idintegerUnique game identifier.
orderintegerDisplay order within the result set.
home_awaycharacterGame venue label ('home' or 'away').
winnerlogicalWinner.
roster_hrefcharacterURL for roster.
hand_typecharacterHand type.
hand_abbreviationcharacterHand abbreviation.
hand_display_valuecharacterHand display value.
ageintegerPlayer age (in years).
date_of_birthcharacterDate of birth (YYYY-MM-DD).
weightintegerPlayer weight in pounds.
display_weightcharacterPlayer weight in display format (e.g. '180 lbs').

Arguments

game_id

Game ID

Author

Saiem Gilani

See Also

Other ESPN WBB Functions: espn_wbb_athletes_index(), espn_wbb_award(), espn_wbb_calendar(), espn_wbb_coach(), espn_wbb_coach_record(), espn_wbb_coach_season(), espn_wbb_coaches(), espn_wbb_conferences(), espn_wbb_franchise(), espn_wbb_franchises(), espn_wbb_game_odds(), espn_wbb_game_official_detail(), espn_wbb_game_play(), espn_wbb_game_play_personnel(), espn_wbb_game_player_box(), espn_wbb_game_probabilities(), espn_wbb_game_propbets(), espn_wbb_game_team_linescores(), espn_wbb_game_team_roster_entry(), espn_wbb_injuries(), espn_wbb_leaders(), espn_wbb_news(), espn_wbb_player_awards(), espn_wbb_player_career_stats(), espn_wbb_player_eventlog_v2(), espn_wbb_player_info(), espn_wbb_player_overview(), espn_wbb_player_seasons(), espn_wbb_player_stats(), espn_wbb_position(), espn_wbb_positions(), espn_wbb_powerindex(), espn_wbb_rankings(), espn_wbb_scoreboard(), espn_wbb_season_awards(), espn_wbb_season_group(), espn_wbb_season_groups(), espn_wbb_season_info(), espn_wbb_season_leaders(), espn_wbb_season_ranking(), espn_wbb_season_rankings(), espn_wbb_season_type(), espn_wbb_season_types(), espn_wbb_season_week(), espn_wbb_season_weeks(), espn_wbb_seasons(), espn_wbb_standings(), espn_wbb_team(), espn_wbb_team_injuries(), espn_wbb_team_news(), espn_wbb_team_record_detail(), espn_wbb_team_schedule(), espn_wbb_team_season_roster(), espn_wbb_team_season_statistics(), espn_wbb_team_stats(), espn_wbb_teams(), espn_wbb_tournament(), espn_wbb_tournament_season(), espn_wbb_tournament_seasons(), espn_wbb_tournaments(), espn_wbb_venues(), espn_wbb_week_ranking(), espn_wbb_week_rankings()

Examples

Run this code
# \donttest{
  try(espn_wbb_game_all(game_id = 401276115))
 # }
# \donttest{
  try(espn_wbb_pbp(game_id = 401498717))
# }
# \donttest{
  try(espn_wbb_team_box(game_id = 401276115))
# }
# \donttest{
  try(espn_wbb_player_box(game_id = 401276115))
# }
# \donttest{
  try(espn_wbb_game_rosters(game_id = 401276115))
# }

Run the code above in your browser using DataLab