Learn R Programming

wehoop (version 3.0.0)

espn_wbb_season_group: Get ESPN WBB Season Group Detail

Description

Returns metadata for one group (conference or division) in one (WBB season x season-type), plus $ref URLs to its parent group, children groups, member teams, and standings.

Returns the list of child groups (e.g. divisions within a conference) for one (WBB season x season-type x parent-group).

Returns the list of team IDs that belong to one group (conference or division) for one (WBB season x season-type).

Usage

espn_wbb_season_group(
  group_id,
  season = most_recent_wbb_season(),
  season_type = 2L,
  ...
)

espn_wbb_season_group_children( group_id, season = most_recent_wbb_season(), season_type = 2L, ... )

espn_wbb_season_group_teams( group_id, season = most_recent_wbb_season(), season_type = 2L, ... )

Value

A single-row tibble.

Columns as documented in the shared espn_basketball_season_group_schema table.

A tibble with one row per child group.

col_nametypesdescription
leaguecharacterLeague slug.
seasonintegerSeason year.
season_typeintegerSeason-type id.
parent_group_idcharacterParent group id (queried).
child_group_idcharacterChild group id.
refcharacter$ref to child group detail.

A tibble with one row per team in the group.

col_nametypesdescription
leaguecharacterLeague slug.
seasonintegerSeason year.
season_typeintegerSeason-type id.
group_idcharacterESPN group id.
team_idcharacterESPN team id.
refcharacter$ref URL to the team-in-season entry.

Arguments

group_id

ESPN group identifier.

season

Season year. Defaults to most recent WBB season.

season_type

Season-type id (2 = regular (default)).

...

Additional arguments; currently unused.

Author

Saiem Gilani

Details

Get ESPN WBB Season Group Detail

Get ESPN WBB Season Group Children Index

Get ESPN WBB Season Group Teams Index

See Also

Other ESPN WBB Functions: espn_wbb_athletes_index(), espn_wbb_award(), espn_wbb_calendar(), espn_wbb_coach(), espn_wbb_coach_record(), espn_wbb_coach_season(), espn_wbb_coaches(), espn_wbb_conferences(), espn_wbb_franchise(), espn_wbb_franchises(), espn_wbb_game_all(), espn_wbb_game_odds(), espn_wbb_game_official_detail(), espn_wbb_game_play(), espn_wbb_game_play_personnel(), espn_wbb_game_player_box(), espn_wbb_game_probabilities(), espn_wbb_game_propbets(), espn_wbb_game_team_linescores(), espn_wbb_game_team_roster_entry(), espn_wbb_injuries(), espn_wbb_leaders(), espn_wbb_news(), espn_wbb_player_awards(), espn_wbb_player_career_stats(), espn_wbb_player_eventlog_v2(), espn_wbb_player_info(), espn_wbb_player_overview(), espn_wbb_player_seasons(), espn_wbb_player_stats(), espn_wbb_position(), espn_wbb_positions(), espn_wbb_powerindex(), espn_wbb_rankings(), espn_wbb_scoreboard(), espn_wbb_season_awards(), espn_wbb_season_groups(), espn_wbb_season_info(), espn_wbb_season_leaders(), espn_wbb_season_ranking(), espn_wbb_season_rankings(), espn_wbb_season_type(), espn_wbb_season_types(), espn_wbb_season_week(), espn_wbb_season_weeks(), espn_wbb_seasons(), espn_wbb_standings(), espn_wbb_team(), espn_wbb_team_injuries(), espn_wbb_team_news(), espn_wbb_team_record_detail(), espn_wbb_team_schedule(), espn_wbb_team_season_roster(), espn_wbb_team_season_statistics(), espn_wbb_team_stats(), espn_wbb_teams(), espn_wbb_tournament(), espn_wbb_tournament_season(), espn_wbb_tournament_seasons(), espn_wbb_tournaments(), espn_wbb_venues(), espn_wbb_week_ranking(), espn_wbb_week_rankings()

Examples

Run this code
# \donttest{
  espn_wbb_season_group(group_id = 5, season = 2025)
# }
# \donttest{
  espn_wbb_season_group_children(group_id = 5, season = 2025)
# }
# \donttest{
  espn_wbb_season_group_teams(group_id = 5, season = 2025)
# }

Run the code above in your browser using DataLab