View source: R/espn_wnba_data.R
| espn_wnba_game_all | R Documentation |
Get ESPN's WNBA game data (play-by-play, team and player box)
Get ESPN's WNBA play by play data
Get ESPN's WNBA team box data
Get ESPN's WNBA player box data
Get ESPN WNBA game rosters
espn_wnba_game_all(game_id)
espn_wnba_pbp(game_id)
espn_wnba_team_box(game_id)
espn_wnba_player_box(game_id)
espn_wnba_game_rosters(game_id)
game_id |
Game ID |
A named list of dataframes: Plays, Team, Player
Plays
Columns as documented in the shared espn_basketball_game_all_plays_schema table.
Team
Columns as documented in the shared espn_basketball_team_box_schema table.
Player
Columns as documented in the shared espn_basketball_game_all_player_schema table.
Returns a play-by-play data frame
Plays
Columns as documented in the shared espn_basketball_game_all_plays_schema table.
Returns a team boxscore data frame
Team
Columns as documented in the shared espn_basketball_team_box_schema table.
Returns a player boxscore data frame
Player
Columns as documented in the shared espn_basketball_game_all_player_schema table.
A game rosters data frame
| col_name | types | description |
| athlete_id | integer | Unique athlete identifier (ESPN). |
| athlete_uid | character | ESPN athlete UID (universal identifier). |
| athlete_guid | character | ESPN athlete GUID. |
| athlete_type | character | Athlete type / class. |
| sdr | integer | Sdr. |
| first_name | character | Player's first name. |
| last_name | character | Player's last name. |
| full_name | character | Player's full name. |
| athlete_display_name | character | Athlete display name (full). |
| short_name | character | Short display name. |
| weight | numeric | Player weight in pounds. |
| display_weight | character | Player weight in display format (e.g. '180 lbs'). |
| height | numeric | Player height (string e.g. '6-2' or inches). |
| display_height | character | Player height in display format (e.g. '6-2'). |
| age | integer | Player age (in years). |
| date_of_birth | character | Date of birth (YYYY-MM-DD). |
| slug | character | URL-safe identifier. |
| headshot_href | character | Headshot image URL. |
| headshot_alt | character | Alternative-text label for the headshot. |
| jersey | character | Jersey number worn by the player. |
| position_id | integer | Unique position identifier. |
| position_name | character | Listed roster position ('Guard', 'Forward', 'Center'). |
| position_display_name | character | Position display name. |
| position_abbreviation | character | Position abbreviation ('G' / 'F' / 'C'). |
| position_leaf | logical | Position leaf. |
| linked | logical | TRUE if the record is linked to a related entity. |
| years | integer | Years. |
| active | logical | TRUE if the row represents an active record (player / team / season). |
| status_id | integer | Status identifier. |
| status_name | character | Status label. |
| status_type | character | Status type. |
| status_abbreviation | character | Status abbreviation. |
| birth_place_city | character | Birth place city. |
| birth_place_state | character | Birth place state. |
| birth_place_country | character | Birth place country. |
| starter | logical | TRUE if the player was in the starting lineup; FALSE otherwise. |
| valid | logical | Valid. |
| did_not_play | logical | TRUE if the player did not appear in the game. |
| display_name | character | Display name. |
| reason | character | Reason. |
| ejected | logical | TRUE if the player was ejected from the game. |
| team_id | integer | Unique team identifier. |
| team_guid | character | ESPN team GUID. |
| team_uid | character | ESPN universal team identifier (UID format 's:40~l:...~t:...'). |
| team_sdr | integer | ESPN team SDR identifier. |
| team_slug | character | URL-safe team identifier (e.g. 'lasvegas-aces' / 'aces'). |
| team_location | character | Team city or location string. |
| team_name | character | Full team display name (e.g. 'Las Vegas Aces'). |
| team_abbreviation | character | Short team abbreviation (e.g. 'LAS'). |
| team_display_name | character | Full team display name. |
| team_short_display_name | character | Short team display name (e.g. 'Aces'). |
| team_color | character | Team primary color (hex without leading '#'). |
| team_alternate_color | character | Team alternate color (hex without leading '#'). |
| team_is_active | logical | TRUE if the team is currently active. |
| is_all_star | logical | Is all star. |
| logo_href | character | Team or league logo URL. |
| logo_dark_href | character | Logo URL for dark backgrounds. |
| logos_href_2 | character | Logos href 2. |
| logos_href_3 | character | Logos href 3. |
| game_id | integer | Unique game identifier. |
| order | integer | Display order within the result set. |
| home_away | character | Game venue label ('home' or 'away'). |
| winner | logical | Winner. |
| draft_display_text | character | Draft display text. |
| draft_round | integer | Round of the draft selection. |
| draft_year | integer | Draft year (4-digit). |
| draft_selection | integer | Draft selection. |
| hand_type | character | Hand type. |
| hand_abbreviation | character | Hand abbreviation. |
| hand_display_value | character | Hand display value. |
| citizenship | character | Citizenship. |
Saiem Gilani
Other ESPN WNBA Functions:
espn_wnba_athletes_index(),
espn_wnba_award(),
espn_wnba_calendar(),
espn_wnba_coach_season(),
espn_wnba_coaches(),
espn_wnba_conferences(),
espn_wnba_draft(),
espn_wnba_draft_athlete_detail(),
espn_wnba_draft_pick(),
espn_wnba_draft_rounds(),
espn_wnba_franchise(),
espn_wnba_franchises(),
espn_wnba_freeagents(),
espn_wnba_futures(),
espn_wnba_game_odds(),
espn_wnba_game_official_detail(),
espn_wnba_game_play(),
espn_wnba_game_play_personnel(),
espn_wnba_game_player_box(),
espn_wnba_game_probabilities(),
espn_wnba_game_propbets(),
espn_wnba_game_team_linescores(),
espn_wnba_game_team_roster_entry(),
espn_wnba_injuries(),
espn_wnba_leaders(),
espn_wnba_news(),
espn_wnba_player_awards(),
espn_wnba_player_career_stats(),
espn_wnba_player_eventlog_v2(),
espn_wnba_player_info(),
espn_wnba_player_overview(),
espn_wnba_player_seasons(),
espn_wnba_player_stats(),
espn_wnba_position(),
espn_wnba_positions(),
espn_wnba_powerindex(),
espn_wnba_scoreboard(),
espn_wnba_season_awards(),
espn_wnba_season_group(),
espn_wnba_season_groups(),
espn_wnba_season_info(),
espn_wnba_season_leaders(),
espn_wnba_season_ranking(),
espn_wnba_season_rankings(),
espn_wnba_season_type(),
espn_wnba_season_types(),
espn_wnba_season_week(),
espn_wnba_season_weeks(),
espn_wnba_seasons(),
espn_wnba_standings(),
espn_wnba_team(),
espn_wnba_team_injuries(),
espn_wnba_team_news(),
espn_wnba_team_record(),
espn_wnba_team_record_detail(),
espn_wnba_team_schedule(),
espn_wnba_team_season_roster(),
espn_wnba_team_season_statistics(),
espn_wnba_team_stats(),
espn_wnba_teams(),
espn_wnba_transactions(),
espn_wnba_venues(),
espn_wnba_week_ranking(),
espn_wnba_week_rankings()
try(espn_wnba_game_all(game_id = 401244185))
try(espn_wnba_pbp(game_id = 401455681))
try(espn_wnba_team_box(game_id = 401244185))
try(espn_wnba_player_box(game_id = 401244185))
try(espn_wnba_game_rosters(game_id = 401244185))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.