Learn R Programming

wehoop (version 3.0.0)

espn_wnba_game_all: Get ESPN's WNBA game data (play-by-play, team and player box)

Description

Get ESPN's WNBA game data (play-by-play, team and player box)

Get ESPN's WNBA play by play data

Get ESPN's WNBA team box data

Get ESPN's WNBA player box data

Get ESPN WNBA game rosters

Usage

espn_wnba_game_all(game_id)

espn_wnba_pbp(game_id)

espn_wnba_team_box(game_id)

espn_wnba_player_box(game_id)

espn_wnba_game_rosters(game_id)

Value

A named list of dataframes: Plays, Team, Player

Plays

Columns as documented in the shared espn_basketball_game_all_plays_schema table.

Team

Columns as documented in the shared espn_basketball_team_box_schema table.

Player

Columns as documented in the shared espn_basketball_game_all_player_schema table.

Returns a play-by-play data frame

Plays

Columns as documented in the shared espn_basketball_game_all_plays_schema table.

Returns a team boxscore data frame

Team

Columns as documented in the shared espn_basketball_team_box_schema table.

Returns a player boxscore data frame

Player

Columns as documented in the shared espn_basketball_game_all_player_schema table.

A game rosters data frame

col_nametypesdescription
athlete_idintegerUnique athlete identifier (ESPN).
athlete_uidcharacterESPN athlete UID (universal identifier).
athlete_guidcharacterESPN athlete GUID.
athlete_typecharacterAthlete type / class.
sdrintegerSdr.
first_namecharacterPlayer's first name.
last_namecharacterPlayer's last name.
full_namecharacterPlayer's full name.
athlete_display_namecharacterAthlete display name (full).
short_namecharacterShort display name.
weightnumericPlayer weight in pounds.
display_weightcharacterPlayer weight in display format (e.g. '180 lbs').
heightnumericPlayer height (string e.g. '6-2' or inches).
display_heightcharacterPlayer height in display format (e.g. '6-2').
ageintegerPlayer age (in years).
date_of_birthcharacterDate of birth (YYYY-MM-DD).
slugcharacterURL-safe identifier.
headshot_hrefcharacterHeadshot image URL.
headshot_altcharacterAlternative-text label for the headshot.
jerseycharacterJersey number worn by the player.
position_idintegerUnique position identifier.
position_namecharacterListed roster position ('Guard', 'Forward', 'Center').
position_display_namecharacterPosition display name.
position_abbreviationcharacterPosition abbreviation ('G' / 'F' / 'C').
position_leaflogicalPosition leaf.
linkedlogicalTRUE if the record is linked to a related entity.
yearsintegerYears.
activelogicalTRUE if the row represents an active record (player / team / season).
status_idintegerStatus identifier.
status_namecharacterStatus label.
status_typecharacterStatus type.
status_abbreviationcharacterStatus abbreviation.
birth_place_citycharacterBirth place city.
birth_place_statecharacterBirth place state.
birth_place_countrycharacterBirth place country.
starterlogicalTRUE if the player was in the starting lineup; FALSE otherwise.
validlogicalValid.
did_not_playlogicalTRUE if the player did not appear in the game.
display_namecharacterDisplay name.
reasoncharacterReason.
ejectedlogicalTRUE if the player was ejected from the game.
team_idintegerUnique team identifier.
team_guidcharacterESPN team GUID.
team_uidcharacterESPN universal team identifier (UID format 's:40~l:...~t:...').
team_sdrintegerESPN team SDR identifier.
team_slugcharacterURL-safe team identifier (e.g. 'lasvegas-aces' / 'aces').
team_locationcharacterTeam city or location string.
team_namecharacterFull team display name (e.g. 'Las Vegas Aces').
team_abbreviationcharacterShort team abbreviation (e.g. 'LAS').
team_display_namecharacterFull team display name.
team_short_display_namecharacterShort team display name (e.g. 'Aces').
team_colorcharacterTeam primary color (hex without leading '#').
team_alternate_colorcharacterTeam alternate color (hex without leading '#').
team_is_activelogicalTRUE if the team is currently active.
is_all_starlogicalIs all star.
logo_hrefcharacterTeam or league logo URL.
logo_dark_hrefcharacterLogo URL for dark backgrounds.
logos_href_2characterLogos href 2.
logos_href_3characterLogos href 3.
game_idintegerUnique game identifier.
orderintegerDisplay order within the result set.
home_awaycharacterGame venue label ('home' or 'away').
winnerlogicalWinner.
draft_display_textcharacterDraft display text.
draft_roundintegerRound of the draft selection.
draft_yearintegerDraft year (4-digit).
draft_selectionintegerDraft selection.
hand_typecharacterHand type.
hand_abbreviationcharacterHand abbreviation.
hand_display_valuecharacterHand display value.
citizenshipcharacterCitizenship.

Arguments

game_id

Game ID

Author

Saiem Gilani

See Also

Other ESPN WNBA Functions: espn_wnba_athletes_index(), espn_wnba_award(), espn_wnba_calendar(), espn_wnba_coach_season(), espn_wnba_coaches(), espn_wnba_conferences(), espn_wnba_draft(), espn_wnba_draft_athlete_detail(), espn_wnba_draft_pick(), espn_wnba_draft_rounds(), espn_wnba_franchise(), espn_wnba_franchises(), espn_wnba_freeagents(), espn_wnba_futures(), espn_wnba_game_odds(), espn_wnba_game_official_detail(), espn_wnba_game_play(), espn_wnba_game_play_personnel(), espn_wnba_game_player_box(), espn_wnba_game_probabilities(), espn_wnba_game_propbets(), espn_wnba_game_team_linescores(), espn_wnba_game_team_roster_entry(), espn_wnba_injuries(), espn_wnba_leaders(), espn_wnba_news(), espn_wnba_player_awards(), espn_wnba_player_career_stats(), espn_wnba_player_eventlog_v2(), espn_wnba_player_info(), espn_wnba_player_overview(), espn_wnba_player_seasons(), espn_wnba_player_stats(), espn_wnba_position(), espn_wnba_positions(), espn_wnba_powerindex(), espn_wnba_scoreboard(), espn_wnba_season_awards(), espn_wnba_season_group(), espn_wnba_season_groups(), espn_wnba_season_info(), espn_wnba_season_leaders(), espn_wnba_season_ranking(), espn_wnba_season_rankings(), espn_wnba_season_type(), espn_wnba_season_types(), espn_wnba_season_week(), espn_wnba_season_weeks(), espn_wnba_seasons(), espn_wnba_standings(), espn_wnba_team(), espn_wnba_team_injuries(), espn_wnba_team_news(), espn_wnba_team_record(), espn_wnba_team_record_detail(), espn_wnba_team_schedule(), espn_wnba_team_season_roster(), espn_wnba_team_season_statistics(), espn_wnba_team_stats(), espn_wnba_teams(), espn_wnba_transactions(), espn_wnba_venues(), espn_wnba_week_ranking(), espn_wnba_week_rankings()

Examples

Run this code
# \donttest{
  try(espn_wnba_game_all(game_id = 401244185))
# }

# \donttest{
   try(espn_wnba_pbp(game_id = 401455681))
# }

# \donttest{
   try(espn_wnba_team_box(game_id = 401244185))
# }
# \donttest{
  try(espn_wnba_player_box(game_id = 401244185))
# }

# \donttest{
  try(espn_wnba_game_rosters(game_id = 401244185))
# }

Run the code above in your browser using DataLab