View source: R/ncaa_wbb_data.R
| ncaa_wbb_NET_rankings | R Documentation |
Get Women's college basketball NET rankings for the current date from the NCAA website
ncaa_wbb_NET_rankings()
Returns a tibble
| col_name | types | description |
| rank | integer | Whether to include statistical ranks in the returned table. |
| previous | integer | Previous. |
| school | character | Player's school / college (when distinct from 'college'). |
| conference | character | Filter players or teams by conference. |
| record | character | Record string (e.g. '12-4'). |
| road | character | Road. |
| neutral | character | Neutral. |
| home | character | Home. |
| non_div_i | character | Non div i. |
Saiem Gilani
# Get current NCAA NET rankings
try(ncaa_wbb_NET_rankings())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.