Learn R Programming

wehoop (version 3.0.0)

ncaa_wbb_NET_rankings: Get Women's college basketball NET rankings for the current date from the NCAA website

Description

Get Women's college basketball NET rankings for the current date from the NCAA website

Usage

ncaa_wbb_NET_rankings()

Arguments

Value

Returns a tibble

col_nametypesdescription
rankintegerWhether to include statistical ranks in the returned table.
previousintegerPrevious.
schoolcharacterPlayer's school / college (when distinct from 'college').
conferencecharacterFilter players or teams by conference.
recordcharacterRecord string (e.g. '12-4').
roadcharacterRoad.
neutralcharacterNeutral.
homecharacterHome.
non_div_icharacterNon div i.

Author

Saiem Gilani

Examples

Run this code
# Get current NCAA NET rankings
# \donttest{
  try(ncaa_wbb_NET_rankings())
# }

Run the code above in your browser using DataLab