View source: R/wnba_stats_leaders.R
| wnba_homepageleaders | R Documentation |
Get WNBA Stats API Homepage Leaders
Get WNBA Stats API Homepage Leaders
wnba_homepageleaders(
league_id = "10",
game_scope = "Season",
player_or_team = "Team",
player_scope = "All Players",
season = most_recent_wnba_season() - 1,
season_type = "Regular Season",
stat_category = "Points",
...
)
league_id |
League - default: '00'. Other options include '10': WWNBA, '20': G-League |
game_scope |
Game Scope - Season, Last 10, ,Yesterday, Finals |
player_or_team |
Player or Team |
player_scope |
Player Scope - All Players, Rookies |
season |
Season - format 2020-21 |
season_type |
Season Type - Regular Season, Playoffs |
stat_category |
Stat Category: Points, Rebounds, Assists, Defense, Clutch, Playmaking, Efficiency, Fast Break, Scoring Breakdown |
... |
Additional arguments passed to an underlying function like httr. |
wnba_homepageleaders(league_id = '10', player_or_team = "Player") wnba_homepageleaders(league_id = '10', player_or_team = "Team")
Returns a named list of data frames: HomePageLeaders, LeagueAverage, LeagueMax
HomePageLeaders
| col_name | types | description |
| RANK | character | Whether to include statistical ranks in the returned table. |
| PLAYERID | character | |
| PLAYER | character | |
| TEAM_ID | character | Unique team identifier. |
| TEAM_ABBREVIATION | character | Short team abbreviation (e.g. 'LAS'). |
| TEAM_NAME | character | Full team display name (e.g. 'Las Vegas Aces'). |
| PTS | character | Points scored. |
| FG_PCT | character | Field goal percentage (0-1). |
| FG3_PCT | character | Three-point field goal percentage (0-1). |
| FT_PCT | character | Free throw percentage (0-1). |
| EFG_PCT | character | Effective field goal percentage (0-1). |
| TS_PCT | character | True shooting percentage (0-1). |
| PTS_PER48 | character | |
LeagueAverage
| col_name | types | description |
| PTS | numeric | Points scored. |
| FG_PCT | numeric | Field goal percentage (0-1). |
| FG3_PCT | numeric | Three-point field goal percentage (0-1). |
| FT_PCT | numeric | Free throw percentage (0-1). |
| EFG_PCT | numeric | Effective field goal percentage (0-1). |
| TS_PCT | numeric | True shooting percentage (0-1). |
| PTS_PER48 | numeric | |
LeagueMax
Same columns as the LeagueAverage table above.
Saiem Gilani
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.