| year_to_season | R Documentation |
Returns a season string of the form YYYY-YY (e.g. 2024 -> "2024-25").
WNBA seasons span a single calendar year, but several Stats API endpoints
(and several NBA-derived endpoints used in load helpers) accept the
two-year season-string form, so this helper is provided for parity with
the analogous helper in the hoopR package.
year_to_season(year)
year |
a four-digit calendar year (numeric or character). |
A character season string, e.g. "2024-25".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.